@@ -5,7 +5,7 @@ from pathlib import Path
 from enum import Enum
 from datetime import timedelta
 from airflow.contrib.operators import kubernetes_pod_operator
-from kubernetes.client.models import V1Volume, V1VolumeMount
+from kubernetes.client.models import V1Volume, V1VolumeMount, V1ResourceRequirements
 from knada_composer_wrappers.init_containers import create_read_bucket_init_container
 
 
@@ -44,6 +44,10 @@ def create_dbt_pod_operator(
         retries=retries,
         retry_delay=retry_delay,
         is_delete_operator_pod=delete_on_completed,
+        container_resources=V1ResourceRequirements(
+            requests={"memory": "512Mi"},
+            limits={"memory": "512Mi"}
+        )
     )
 
 
@@ -83,6 +87,10 @@ def create_python_pod_operator(
         retry_delay=retry_delay,
         startup_timeout_seconds=startup_timeout_seconds,
         is_delete_operator_pod=delete_on_completed,
+        container_resources=V1ResourceRequirements(
+            requests={"memory": "512Mi"},
+            limits={"memory": "512Mi"}
+        )
     )
 
 
@@ -128,4 +136,8 @@ def create_nb_pod_operator(
         retry_delay=retry_delay,
         startup_timeout_seconds=startup_timeout_seconds,
         is_delete_operator_pod=delete_on_completed,
+        container_resources=V1ResourceRequirements(
+            requests={"memory": "512Mi"},
+            limits={"memory": "512Mi"}
+        )
     )
