@@ -15,4 +15,8 @@ def create_read_bucket_init_container(bucket_path: str):
         args=[
             f"gsutil cp -r gs://{os.environ['GCS_BUCKET']}/{bucket_path}/* data/"
         ],
+        resources=k8s.V1ResourceRequirements(
+            requests={"memory": "512Mi"},
+            limits={"memory": "512Mi"}
+        )
     )
